@@ -5,11 +5,11 @@ This SDK provides a simple interface to interact with the
 DriveMonitor backend for analyzing driving videos.
 """
 
-__version__ = "0.0.17"  # This will be the clean version for PyPI (Overwritten by CI)
-__build__ = "cf337f7"      # This will hold the commit hash or full build string, populated by CI
+__version__ = "0.1.15"  # This will be the clean version for PyPI (Overwritten by CI)
+__build__ = "fd88e50"      # This will hold the commit hash or full build string, populated by CI
 
 from .client import NomadicML, DEFAULT_BASE_URL, DEFAULT_COLLECTION_NAME
-from .video import VideoClient, AnalysisType
+from .video import VideoClient
 from .exceptions import NomadicMLError, AuthenticationError, APIError, VideoUploadError, AnalysisError
 from .types import VideoSource, ProcessingStatus
 
@@ -30,7 +30,6 @@ NomadicML.__init__ = _patched_init
 __all__ = [
     "NomadicML",
     "VideoClient",
-    "AnalysisType",
     "NomadicMLError",
     "AuthenticationError",
     "APIError",
