@@ -35,13 +35,8 @@ VideoIDList  = Sequence[VideoID]
 
 class AnalysisType(str, Enum):
     EDGE_CASE      = "edge_case"
-    TURN_AGENT     = "turn_agent"
-    LANE_CHANGE_AGENT = "lane_change_agent"
-    EDGE_CASE_AGENT = "edge_case_agent"
-    RELATIVE_MOTION_AGENT = "relative_motion_agent"
-    VIOLATION_AGENT = "violation_agent"
-    ASK            = "rapid_review"
-    SEARCH         = "search"  # DEPRECATED - kept for backwards compatibility
+    SEARCH         = "search"
+    RAPID_REVIEW   = "rapid_review" 
 
 class CustomCategory(str, Enum):
     DRIVING        = "driving"
@@ -635,36 +630,25 @@ class VideoClient:
                          edge_case_category: str | None,
                          custom_category: CustomCategory | str | None):
         """Ensure required kwargs are provided for each analysis type."""
-        # Check for deprecated 'search' analysis type or search_query parameter
-        if analysis_type == "search" or search_query:
-            import warnings
-            warnings.warn(
-                "analysis_type='search' and search_query parameter are deprecated and have been removed. "
-                "Use analysis_type='rapid_review' with custom_event parameter instead "
-                "for searching in videos of any length.",
-                DeprecationWarning,
-                stacklevel=3
-            )
-            raise ValueError(
-                "analysis_type='search' and search_query parameter have been removed. "
-                "Use analysis_type='rapid_review' with custom_event=<your_search_query> instead."
-            )
-        
         if analysis_type is None or analysis_type not in [cat.value for cat in AnalysisType]:
             valid_values = ", ".join([f"'{cat.value}'" for cat in AnalysisType])
-            raise ValueError(f"analysis_type must be one of {valid_values}")
-        if custom_event and analysis_type != AnalysisType.ASK:
-            raise ValueError("custom_event is only allowed when analysis_type='rapid_review'")
-        if edge_case_category and analysis_type not in [AnalysisType.EDGE_CASE]:
-            raise ValueError("edge_case_category is only allowed when analysis_type='edge_case'")
-        if custom_category and analysis_type != AnalysisType.ASK:
-            raise ValueError("custom_category is only allowed when analysis_type='ask'")
+            raise ValueError(f"analysis_type must be one of {valid_values}")        
 
-        if analysis_type == AnalysisType.ASK and not custom_event:
-            raise ValueError("custom_event is required when analysis_type='ask'")
+        if search_query and analysis_type != AnalysisType.SEARCH:
+            raise ValueError("search_query is only allowed when analysis_type='search'")
+        if custom_event and analysis_type != AnalysisType.RAPID_REVIEW:
+            raise ValueError("custom_event is only allowed when analysis_type='rapid_review'")
+        if edge_case_category and analysis_type != AnalysisType.EDGE_CASE:
+            raise ValueError("edge_case_category is only allowed when analysis_type='edge_case'")
+        if custom_category and analysis_type != AnalysisType.RAPID_REVIEW:
+            raise ValueError("custom_category is only allowed when analysis_type='rapid_review'")
+
+        if analysis_type == AnalysisType.SEARCH and not search_query:
+            raise ValueError("search_query is required when analysis_type='search'")
+        if analysis_type == AnalysisType.RAPID_REVIEW and not custom_event:
+            raise ValueError("custom_event is required when analysis_type='rapid_review'")
         if analysis_type == AnalysisType.EDGE_CASE and not edge_case_category:
             raise ValueError("edge_case_category is required when analysis_type='edge_case'")
-        # Agent types don't need edge_case_category since they have predefined categories
         if custom_category is not None and custom_category not in [cat.value for cat in CustomCategory]:
             valid_values = ", ".join([f"'{cat.value}'" for cat in CustomCategory])
             raise ValueError(f"custom_category must be one of {valid_values}")
@@ -693,8 +677,17 @@ class VideoClient:
                         custom_category=custom_category)
 
         # 2) dispatch by AnalysisType
+        if analysis_type == AnalysisType.SEARCH:
+            sweep = self.search_events(video_id, search_query, model_id=model_id,
+                                    timeout=timeout)
+            return {
+                "video_id": video_id,
+                "mode":     "search",
+                "status":   "completed",
+                "hits":     sweep.get("hits", []),
+            }
 
-        if analysis_type == AnalysisType.ASK:
+        if analysis_type == AnalysisType.RAPID_REVIEW:
             response = self._custom_event_detection(
                 video_id=video_id,
                 custom_category=custom_category,
@@ -727,77 +720,16 @@ class VideoClient:
                 "events":   events,
             }
 
-        # Handle agent-based analyses and legacy edge case
+        # EDGE_CASE analysis
         analysis_id = None
-        mode_label = "edge_case"
-        
-        # For agent types, set the appropriate edge_case_category
-        # The backend's defaults_map will handle the specific edge cases
-        if analysis_type == AnalysisType.EDGE_CASE_AGENT:
-            # General edge case agent - uses AI to determine edge cases
-            result = self.analyze_video_edge(
-                video_id=video_id,
-                edge_case_category="agent_mode_placeholder",
-                model_id=model_id,
-                concept_ids=concept_ids,
-                mode="agent"
-            )
-            analysis_id = result.get("analysis_id")
-            
-        elif analysis_type == AnalysisType.TURN_AGENT:
-            # Turn detection - backend maps "Vehicle Turns" to the correct edge cases
-            result = self.analyze_video_edge(
-                video_id=video_id,
-                edge_case_category="Vehicle Turns",
-                model_id=model_id,
-                concept_ids=concept_ids,
-                mode="assistant"
-            )
-            analysis_id = result.get("analysis_id")
-            
-        elif analysis_type == AnalysisType.LANE_CHANGE_AGENT:
-            # Lane change detection - backend maps this category
-            result = self.analyze_video_edge(
-                video_id=video_id,
-                edge_case_category="Lane Change Detection",
-                model_id=model_id,
-                concept_ids=concept_ids,
-                mode="assistant"
-            )
-            analysis_id = result.get("analysis_id")
-            
-        elif analysis_type == AnalysisType.RELATIVE_MOTION_AGENT:
-            # Relative motion analysis - backend maps this category
-            result = self.analyze_video_edge(
-                video_id=video_id,
-                edge_case_category="Relative Motion Analysis",
-                model_id=model_id,
-                concept_ids=concept_ids,
-                mode="assistant"
-            )
-            analysis_id = result.get("analysis_id")
-        
-        elif analysis_type == AnalysisType.VIOLATION_AGENT:
-
-            result = self.analyze_video_edge(
-                video_id=video_id,
-                edge_case_category="Driving Violations",
-                model_id=model_id,
-                concept_ids=concept_ids,
-                mode="assistant"
-            )
-            analysis_id = result.get("analysis_id")
-
-        # Legacy EDGE_CASE analysis (for backward compatibility)
-        elif analysis_type == AnalysisType.EDGE_CASE:
-            result = self.analyze_video_edge(
-                video_id=video_id,
-                edge_case_category=edge_case_category,
-                model_id=model_id,
-                concept_ids=concept_ids,
-                mode=mode
-            )
+        if analysis_type == AnalysisType.EDGE_CASE:
+            result = self.analyze_video_edge(video_id=video_id,
+                                    edge_case_category=edge_case_category,
+                                    model_id=model_id,
+                                    concept_ids=concept_ids,
+                                    mode=mode)
             analysis_id = result.get("analysis_id")
+            mode_label = "edge_case"
 
         # 3) optionally wait
         if not wait_for_completion:
@@ -971,9 +903,6 @@ class VideoClient:
         Args:
             video_id: The ID of the uploaded video.
             edge_case_category: Category string used to select the edge case pipeline.
-                For assistant mode with known categories ("Lane Change Detection",
-                "Vehicle Turns", "Relative Motion Analysis"), the backend will
-                automatically apply the appropriate edge cases.
             model_id: (Optional) model to use.
             concept_ids: (Optional) extra concept IDs used by the backend.
             mode: ``"assistant"`` or ``"agent"``.
@@ -1227,21 +1156,32 @@ class VideoClient:
         # The response should already be in the correct format
         return resp.json()
     
-    ###############
-    # ──────────────── Deprecated Methods ────────────────────────────────────────
+    ############### 
+    # ──────────────── Long Video Event Search ────────────────────────────────────────
     ###############
 
     def apply_search(self, parent_id: str, query: str,
                     model_id: str = "Nomadic-VL-XLarge") -> Dict[str, Any]:
-        """
-        DEPRECATED: This method has been removed.
-        Use analyze() with analysis_type='rapid_review' instead.
-        """
-        raise NomadicMLError(
-            "apply_search has been deprecated. Use analyze() with analysis_type='rapid_review' instead, "
-            "which now supports all video lengths including long videos."
+        payload = {
+            "query":      query,
+            "model_id":   model_id,
+            "collection": self.client.collection_name,
+        }
+        r = self.client._make_request(
+            "POST", f"/api/videos/{parent_id}/apply-search", data=payload
         )
+        if r.status_code >= 400:
+            raise NomadicMLError(format_error_message(r.json()))
+        return r.json()                       # {"sweep_id": "...", ...}
 
+    def get_sweep_status(self, parent_id: str, sweep_id: str) -> Dict[str, Any]:
+        params = {"collection": self.client.collection_name}
+        r = self.client._make_request(
+            "GET", f"/api/videos/{parent_id}/sweeps/{sweep_id}", params=params
+        )
+        if r.status_code >= 400:
+            raise NomadicMLError(format_error_message(r.json()))
+        return r.json()
 
     def _get_analysis_status(self, video_id: str, analysis_id: str) -> Dict[str, Any]:
         """Get the current status of a rapid review analysis."""
@@ -1253,6 +1193,21 @@ class VideoClient:
             raise NomadicMLError(format_error_message(r.json()))
         return r.json()
 
+    def wait_for_search(self, parent_id: str, sweep_id: str,
+                        timeout: int = 1_800, poll_interval: int = 5) -> Dict[str, Any]:
+        start = time.time()
+        while True:
+            p = self.get_sweep_status(parent_id, sweep_id)
+            status = (p.get("status") or "").upper()
+            progress = int(p.get("progress", 0))
+            self._print_status_bar(sweep_id,
+                        percent=progress,
+                        status="SEARCH")
+            if status in {"SUCCEEDED", "FAILED"}:
+                return p
+            if time.time() - start > timeout:
+                raise TimeoutError(f"Sweep {sweep_id} timed-out after {timeout}s")
+            time.sleep(poll_interval)
 
     def _wait_for_rapid_review(self, video_id: str, analysis_id: str,
                               timeout: int = 3_600, poll_interval: int = 5,
@@ -1322,6 +1277,12 @@ class VideoClient:
                 raise TimeoutError(f"Rapid review {analysis_id} timed-out after {timeout}s")
             time.sleep(poll_interval)
 
+    def search_events(self, parent_id: str, query: str, *,
+                    model_id: str = "Nomadic-VL-XLarge",
+                    timeout: int = 1_800, poll_interval: int = 5) -> Dict[str, Any]:
+        sweep = self.apply_search(parent_id, query, model_id)
+        return self.wait_for_search(parent_id, sweep["sweep_id"],
+                                    timeout=timeout, poll_interval=poll_interval)
 
     def my_videos(self, folder_id: str | None = None) -> List[Dict[str, Any]]:
         params = {
